@@ -2,7 +2,7 @@
 ####### Update : 2022-05-24     ######
 ######################################
 
-
+import os
 #from ._version import version_info, __version__
 from witcher import Recommender
 from witcher import StockMarket
@@ -10,7 +10,12 @@ from witcher import FileChooser
 from witcher import ImageToCartoon
 from witcher import Portfolio_Advisor
 
-def How_read_Witchwr():
+
+
+__version__=0.0.34
+
+
+def How_To_Use_Witchwr():
     """
     from witcher import FileChooser
         FileChooser.Filechooser ==>
@@ -52,6 +57,6 @@ def How_read_Witchwr():
         portfolio=Portfolio_Advisor()
         
     """
-    return help(How_read_Witchwr)
+    return help(How_To_Use_Witchwr)
 
 
